{% extends 'preview_base.html' %}
{% block body %}
<div class="row">
  <div class="large-12 columns">
    <h1>Template List</h1>
  </div>
</div>
<div class="row">
  <div class="large-12 columns">
    <ul>
      {% for template in templates %}
      <li><a href="{% url 'template-detail' template %}">{{ template }}</a></li>
      {% endfor %}
    </ul>
  </div>
</div>
{% endblock body %}
