{% load static %}
<!doctype html>
<html class="no-js" lang="en" dir="ltr">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ title }}</title>
    <link rel="stylesheet" href={% static 'css/foundation.css' %}>
    <link rel="stylesheet" href={% static 'css/app.css' %}>
  </head>
  <body>
  {% block body %}
  {% endblock body %}
    <script src={% static "js/vendor/jquery.js" %}></script>
    <script src={% static "js/vendor/what-input.js" %}></script>
    <script src={% static "js/vendor/foundation.js" %}></script>
    <script src={% static "js/app.js" %}></script>
    {% block extra_js %}{% endblock extra_js %}
  </body>
</html>
